<!DOCTYPE TS><TS>
<context>
    <name>DatabaseBox</name>
    <message>
        <source>Select music to be played:</source>
        <translation type="obsolete">Vælg musikken, der skal spilles:</translation>
    </message>
    <message>
        <source>Active Play Queue</source>
        <translation>Aktiv spillekø</translation>
    </message>
    <message>
        <source>All My Playlists</source>
        <translation>Alle mine musiklister</translation>
    </message>
    <message>
        <source>All My Music</source>
        <translation>Al min musik</translation>
    </message>
    <message>
        <source>Move to Active Play Queue</source>
        <translation>Flyt til aktiv spillekø</translation>
    </message>
    <message>
        <source>Delete This Playlist</source>
        <translation>Slet denne musikliste</translation>
    </message>
    <message>
        <source>Rename This Playlist</source>
        <translation>Omdøb denne musikliste</translation>
    </message>
    <message>
        <source>Copy To New Playlist</source>
        <translation>Kopiér til ny musikliste</translation>
    </message>
    <message>
        <source>Clear the Active Play Queue</source>
        <translation>Ryd aktiv spillekø</translation>
    </message>
    <message>
        <source>Save Back to Playlist Tree</source>
        <translation>Gem tilbage til musikliste træet</translation>
    </message>
    <message>
        <source>Blechy Blech Blah</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All My Music ~ Loading Music Data </source>
        <translation>Al min musik ~ Indlæser musik</translation>
    </message>
    <message>
        <source>Loading Music Data</source>
        <translation>Indlæser musik</translation>
    </message>
    <message>
        <source>The theme you are using does not contain a &apos;musictree&apos; element.  Please contact the theme creator and ask if they could please update it.&lt;br&gt;&lt;br&gt;The next screen will be empty.  Escape out of it to return to the menu.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Couldn&apos;t create CD</source>
        <translation>Kunne ikke generere CD</translation>
    </message>
    <message>
        <source>CD Created</source>
        <translation>CD genereret</translation>
    </message>
    <message>
        <source>CD-RW Blanking Progress</source>
        <translation>CD-RW slettes</translation>
    </message>
    <message>
        <source>Create Audio CD from Playlist</source>
        <translation>Dan almindelig musik-CD fra spilleliste</translation>
    </message>
    <message>
        <source>Create MP3 CD from Playlist</source>
        <translation>Generér MP3-CD fra spilleliste</translation>
    </message>
    <message>
        <source>Clear CD-RW Disk</source>
        <translation>Slet CD-RW disk</translation>
    </message>
    <message>
        <source>The theme you are using does not contain any info lines in the music element.  Please contact the theme creator and ask if they could please update it.&lt;br&gt;&lt;br&gt;The next screen will be empty.  Escape out of it to return to the menu.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artist:<byte value="x9"/></source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Album:<byte value="x9"/></source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title:<byte value="x9"/></source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length:<byte value="x9"/></source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Genre: </source>
        <translation type="unfinished">Genre:</translation>
    </message>
    <message>
        <source>Compilation Artist:<byte value="x9"/></source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditMetadataDialog</name>
    <message>
        <source>Done</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DB Statistics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Various Artists</source>
        <translation type="unfinished">Diverse kunstnere</translation>
    </message>
    <message>
        <source>Select an Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select a Compilation Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select an Album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select a Genre</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save to Database Only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save to File Only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save to File and Database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit/Do Not Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to save the modified metadata to the file?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PlaybackBox</name>
    <message>
        <source>Edit Playlist</source>
        <translation type="obsolete">Redigér musikliste</translation>
    </message>
    <message>
        <source>Visualize</source>
        <translation type="obsolete">Visualisér</translation>
    </message>
    <message>
        <source>3 Edit Playlist</source>
        <translation type="obsolete">3 Redigér musikliste</translation>
    </message>
    <message>
        <source>4 Visualize</source>
        <translation type="obsolete">4 Visualisér</translation>
    </message>
    <message>
        <source>1 Shuffle: Smart</source>
        <translation type="obsolete">1 Bland: Smart</translation>
    </message>
    <message>
        <source>Shuffle: Smart</source>
        <translation type="obsolete">Bland: Smart</translation>
    </message>
    <message>
        <source>1 Shuffle: Rand</source>
        <translation type="obsolete">1 Bland: Tilfældigt</translation>
    </message>
    <message>
        <source>Shuffle: Rand</source>
        <translation type="obsolete">Bland: Tilfældigt</translation>
    </message>
    <message>
        <source>1 Shuffle: None</source>
        <translation type="obsolete">1 Bland: Ingen</translation>
    </message>
    <message>
        <source>Shuffle: None</source>
        <translation type="obsolete">Bland: Ingen</translation>
    </message>
    <message>
        <source>2 Repeat: All</source>
        <translation type="obsolete">2 Gentag: Alle</translation>
    </message>
    <message>
        <source>Repeat: All</source>
        <translation type="obsolete">Gentag: Alle</translation>
    </message>
    <message>
        <source>2 Repeat: Track</source>
        <translation type="obsolete">2 Gentag: Spor</translation>
    </message>
    <message>
        <source>Repeat: Track</source>
        <translation type="obsolete">Gentag: Spor</translation>
    </message>
    <message>
        <source>2 Repeat: None</source>
        <translation type="obsolete">2 Gentag: Ingen</translation>
    </message>
    <message>
        <source>Repeat: None</source>
        <translation type="obsolete">Gentag: Ingen</translation>
    </message>
    <message>
        <source>Playing stream.</source>
        <translation type="obsolete">Afspiller musik.</translation>
    </message>
    <message>
        <source>Buffering stream.</source>
        <translation type="obsolete">Forbereder musik.</translation>
    </message>
    <message>
        <source>Stream paused.</source>
        <translation type="obsolete">Musik sat på pause.</translation>
    </message>
    <message>
        <source>Output error.</source>
        <translation type="obsolete">Output-fejl.</translation>
    </message>
    <message>
        <source>Stream stopped.</source>
        <translation type="obsolete">Musik stoppet.</translation>
    </message>
    <message>
        <source>Finished playing stream.</source>
        <translation type="obsolete">Musik afsluttet.</translation>
    </message>
    <message>
        <source>Decoder error.</source>
        <translation type="obsolete">Dekoder-fejl.</translation>
    </message>
    <message>
        <source>playlist root</source>
        <translation type="obsolete">rod af spilleliste</translation>
    </message>
    <message>
        <source>ch</source>
        <translation type="obsolete">kanaler</translation>
    </message>
</context>
<context>
    <name>PlaybackBoxMusic</name>
    <message>
        <source>Edit Playlist</source>
        <translation type="unfinished">Redigér musikliste</translation>
    </message>
    <message>
        <source>Visualize</source>
        <translation type="unfinished">Visualisér</translation>
    </message>
    <message>
        <source>3 Edit Playlist</source>
        <translation type="unfinished">3 Redigér musikliste</translation>
    </message>
    <message>
        <source>4 Visualize</source>
        <translation type="unfinished">4 Visualisér</translation>
    </message>
    <message>
        <source>1 Shuffle: Smart</source>
        <translation type="unfinished">1 Bland: Smart</translation>
    </message>
    <message>
        <source>Shuffle: Smart</source>
        <translation type="unfinished">Bland: Smart</translation>
    </message>
    <message>
        <source>1 Shuffle: Rand</source>
        <translation type="unfinished">1 Bland: Tilfældigt</translation>
    </message>
    <message>
        <source>Shuffle: Rand</source>
        <translation type="unfinished">Bland: Tilfældigt</translation>
    </message>
    <message>
        <source>1 Shuffle: None</source>
        <translation type="unfinished">1 Bland: Ingen</translation>
    </message>
    <message>
        <source>Shuffle: None</source>
        <translation type="unfinished">Bland: Ingen</translation>
    </message>
    <message>
        <source>2 Repeat: All</source>
        <translation type="unfinished">2 Gentag: Alle</translation>
    </message>
    <message>
        <source>Repeat: All</source>
        <translation type="unfinished">Gentag: Alle</translation>
    </message>
    <message>
        <source>2 Repeat: Track</source>
        <translation type="unfinished">2 Gentag: Spor</translation>
    </message>
    <message>
        <source>Repeat: Track</source>
        <translation type="unfinished">Gentag: Spor</translation>
    </message>
    <message>
        <source>2 Repeat: None</source>
        <translation type="unfinished">2 Gentag: Ingen</translation>
    </message>
    <message>
        <source>Repeat: None</source>
        <translation type="unfinished">Gentag: Ingen</translation>
    </message>
    <message>
        <source>playlist root</source>
        <translation type="unfinished">rod af spilleliste</translation>
    </message>
    <message>
        <source>Playing stream.</source>
        <translation type="unfinished">Afspiller musik.</translation>
    </message>
    <message>
        <source>Buffering stream.</source>
        <translation type="unfinished">Forbereder musik.</translation>
    </message>
    <message>
        <source>Stream paused.</source>
        <translation type="unfinished">Musik sat på pause.</translation>
    </message>
    <message>
        <source>ch</source>
        <translation type="unfinished">kanaler</translation>
    </message>
    <message>
        <source>Output error.</source>
        <translation type="unfinished">Output-fejl.</translation>
    </message>
    <message>
        <source>Stream stopped.</source>
        <translation type="unfinished">Musik stoppet.</translation>
    </message>
    <message>
        <source>Finished playing stream.</source>
        <translation type="unfinished">Musik afsluttet.</translation>
    </message>
    <message>
        <source>Decoder error.</source>
        <translation type="unfinished">Dekoder-fejl.</translation>
    </message>
    <message>
        <source>kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>kHz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Smart playlists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Tracks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tracks by current Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tracks from current Album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tracks from current Genre</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tracks from current Year</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Searching for music files</source>
        <translation>Søger efter musik-filer</translation>
    </message>
    <message>
        <source>Updating music database</source>
        <translation>Opdaterer musik-databasen</translation>
    </message>
    <message>
        <source>BumpScope</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Various Artists</source>
        <translation>Diverse kunstnere</translation>
    </message>
    <message>
        <source>Ogg Vorbis Audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Ukendt</translation>
    </message>
    <message>
        <source>FLAC Audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Directory to hold music</source>
        <translation>Bibliotek der indeholder musik</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythMusic needs to have write permission to the directory.</source>
        <translation>Dette underbibliotek skal eksistere, og brugeren der kører MythMusic skal have skrive-rettigheder hertil.</translation>
    </message>
    <message>
        <source>Audio device</source>
        <translation>Lyd-enhed</translation>
    </message>
    <message>
        <source>Audio Device used for playback.</source>
        <translation>Lyd-enhed, der anvendes til afspilning</translation>
    </message>
    <message>
        <source>CD device</source>
        <translation>CD-enhed</translation>
    </message>
    <message>
        <source>CDRom device used for ripping/playback.</source>
        <translation>CDROM-enhed der anvendes til kopiering (rip) og afspilning af CD&apos;er.</translation>
    </message>
    <message>
        <source>Tree Sorting</source>
        <translation>Sortering af træ</translation>
    </message>
    <message>
        <source>Script Path</source>
        <translation>Sti til script</translation>
    </message>
    <message>
        <source>If present this script will be executed after a CD Rip is completed.</source>
        <translation>Hvis dette er udfyldt, vil det angivne script blive udført efter en CD er kopieret (rippet).</translation>
    </message>
    <message>
        <source>Filename Format</source>
        <translation>Format af filnavne</translation>
    </message>
    <message>
        <source>Directory and filename Format used to grab information if no ID3 information is found.</source>
        <translation>Formatet af underbiblioteker og filnavne, der anvendendes når der ikke er ID3-information tilgængelig.</translation>
    </message>
    <message>
        <source>Ignore ID3 Tags</source>
        <translation>Ignorér ID3-information</translation>
    </message>
    <message>
        <source>If set, MythMusic will skip checking ID3 tags in files and just try to determine Genre, Artist, Album, and Track number and title from the filename.</source>
        <translation>Hvis dette felt er markeret, vil MythMusic ikke læste information fra de såkaldte ID3-tags, og blot forsøge at fastlægge genre, kunstner, album, spor-nummmer, og titel udfra filnavnet.</translation>
    </message>
    <message>
        <source>Automatically lookup CDs</source>
        <translation>Hent CD-information automatisk</translation>
    </message>
    <message>
        <source>Automatically lookup an audio CD if it is present and show its information in the Music Selection Tree.</source>
        <translation>Hvis dette felt er markeret, vil MythMusic automatisk hente information om CD&apos;er i drevet og vise denne.</translation>
    </message>
    <message>
        <source>Use Keyboard/Remote Accelerated Buttons</source>
        <translation>Anvend accelererede taster på tastatur &amp; fjernbetjening</translation>
    </message>
    <message>
        <source>If this is not set, you will need to use arrow keys to select and activate various functions.</source>
        <translation>Hvis dette felt ikke er markeret, skal du anvende piletaster til at vælge og aktivere diverse funktionaliteter.</translation>
    </message>
    <message>
        <source>Encoding</source>
        <translation>Musik-format</translation>
    </message>
    <message>
        <source>Ogg Vorbis</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lame (MP3)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio encoder to use for CD ripping. Note that the quality level &apos;Perfect&apos; will use the FLAC encoder.</source>
        <translation>Formatet der anvendes ved kopiering (rip) af CD&apos;er. Bemærk, at kvalitetsniveauet &apos;Perfekt&apos; vil resultere i anvendelsen af FLAC-formatet.</translation>
    </message>
    <message>
        <source>File storage location</source>
        <translation>Fil-placering</translation>
    </message>
    <message>
        <source>Defines the location/name for new songs. Valid tokens are: GENRE, ARTIST, ALBUM, TRACK, TITLE, YEAR, / and -. &apos;-&apos; will be replaced by the Token separator</source>
        <translation>Placeringen af nye musik-filer. Gyldige makroer er: GENRE, ARTIST, ALBUM, TRACK, TITLE, YEAR, / og -. &apos;-&apos; vil blive erstattet af makro-separatoreren.</translation>
    </message>
    <message>
        <source>Token separator</source>
        <translation>Makro-separator</translation>
    </message>
    <message>
        <source> - </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filename tokens will be separated by this string.</source>
        <translation>Filnavns-makroer vil blive separeret af denne streng.</translation>
    </message>
    <message>
        <source>Replace &apos; &apos; with &apos;_&apos;</source>
        <translation>Erstat &apos; &apos; med &apos;_&apos;</translation>
    </message>
    <message>
        <source>If set, whitespace characters in filenames will be replaced with underscore characters.</source>
        <translation>Hvis dette felt er markeret, vil mellemrum i filnavne blive erstattet af &apos;underscore&apos;.</translation>
    </message>
    <message>
        <source>Paranoia Level</source>
        <translation>Paranoia-niveau</translation>
    </message>
    <message>
        <source>Full</source>
        <translation>Færre fejl</translation>
    </message>
    <message>
        <source>Faster</source>
        <translation>Hurtigt</translation>
    </message>
    <message>
        <source>Paranoia level of the CD ripper. Set to faster if you&apos;re not concerned about possible errors in the audio.</source>
        <translation>Fastsætter trade-off imellem hastighed og antal fejl ved kopiering (rip) af CD&apos;er. Sæt dette til &apos;hurtigt&apos; hvis du er ligeglad med eventuelle fejl i de færdige lyd-filer.</translation>
    </message>
    <message>
        <source>Automatically eject CDs after ripping</source>
        <translation>Skub automatisk skuffen ud efter kopiering</translation>
    </message>
    <message>
        <source>If set, the CD tray will automatically open after the CD has been ripped.</source>
        <translation>Hvis dette felt er markeret, vil CD-skuffen automatisk blive skubbet ud efter en CD er kopieret (rippet).</translation>
    </message>
    <message>
        <source>Rating Weight</source>
        <translation>Vægt, karakter</translation>
    </message>
    <message>
        <source>Used in &quot;Smart&quot; Shuffle mode. This weighting affects how much strength is given to your rating of a given track when ordering a group of songs.</source>
        <translation>Anvendes ved afspilning med &quot;Bland: Smart&quot;. Denne vægt fastsætter hvor meget din karakter af en given sang betyder ved sortering af en gruppe sange.</translation>
    </message>
    <message>
        <source>Play Count Weight</source>
        <translation>Vægt, hyppighed</translation>
    </message>
    <message>
        <source>Used in &quot;Smart&quot; Shuffle mode. This weighting affects how much strength is given to how many times a given track has been played when ordering a group of songs.</source>
        <translation>Anvendes ved afspilning med &quot;Bland: Smart&quot;. Denne vægt fastsætter hvor meget afspilnings-hyppigheden for en given sang betyder ved sortering af en gruppe sange.</translation>
    </message>
    <message>
        <source>Last Play Weight</source>
        <translation>Vægt, sidst spillet</translation>
    </message>
    <message>
        <source>Used in &quot;Smart&quot; Shuffle mode. This weighting affects how much strength is given to how long it has been since a given track was played when ordering a group of songs.</source>
        <translation>Anvendes ved afspilning med &quot;Bland: Smart&quot;. Denne vægt fastsætter hvor meget længden af tidsrummet siden sidste afspilning af en given sang betyder ved sortering af en gruppe sange.</translation>
    </message>
    <message>
        <source>Random Weight</source>
        <translation>Vægt, tilfældighed</translation>
    </message>
    <message>
        <source>Used in &quot;Smart&quot; Shuffle mode. This weighting affects how much strength is given to good old (peudo-)randomness when ordering a group of songs.</source>
        <translation>Anvendes ved afspilning med &quot;Bland: Smart&quot;. Denne vægt fastsætter hvor meget tilfældigheder spiller ind ved sortering af en gruppe sange.</translation>
    </message>
    <message>
        <source>Show Song Ratings</source>
        <translation>Vis karakterer</translation>
    </message>
    <message>
        <source>Show song ratings on the playback screen.</source>
        <translation>Hvis dette felt er markeret, vil karakterer for de enkelte sange blive vist i afspilnings-skærmbilledet.</translation>
    </message>
    <message>
        <source>List as Shuffled</source>
        <translation>Vis tilfældig rækkefølge</translation>
    </message>
    <message>
        <source>List songs on the playback screen in the order they will be played.</source>
        <translation>Vis sange i afspilnings-skærmbilledet i den rækkefølge de bliver afspillet tilfældigt.</translation>
    </message>
    <message>
        <source>Show entire music tree</source>
        <translation>Vis hele musik-hierarkiet</translation>
    </message>
    <message>
        <source>If selected, you can navigate your entire music tree from the playing screen.</source>
        <translation>Hvis dette felt er markeret, kan du navigere rundt i hele musik-hierarkiet i afspilnings-skærmbilledet.</translation>
    </message>
    <message>
        <source>Play mode</source>
        <translation>Afspilnings-måde</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Tilfældig</translation>
    </message>
    <message>
        <source>Intelligent</source>
        <translation>Smart</translation>
    </message>
    <message>
        <source>Starting shuffle mode for the player.  Can be either normal, random, or intelligent (random).</source>
        <translation>Fastsætter hvordan afspilning foregår som standard.</translation>
    </message>
    <message>
        <source>Delay before Visualizations start (seconds)</source>
        <translation>Forsinkelse før visualiseringer starter (sekunder)</translation>
    </message>
    <message>
        <source>If set to 0, visualizations will never automatically start.</source>
        <translation>Hvis denne værdi sættes til 0, vil visualiseringer aldrig starte automatisk</translation>
    </message>
    <message>
        <source>Change Visualizer on each song</source>
        <translation>Skift visualisering ved hver sang</translation>
    </message>
    <message>
        <source>Change the visualizer when the song change.</source>
        <translation>Fastsætter om visualiseringen skal skifte ved hver ny sang.</translation>
    </message>
    <message>
        <source>Width for Visual Scaling</source>
        <translation>Vandret skalering af visualisering</translation>
    </message>
    <message>
        <source>If set to &quot;2&quot;, visualizations will be scaled in half.  Currently only used by the goom visualization.  Reduces CPU load on slower machines.</source>
        <translation>Hvis denne værdi sættes til &apos;2&apos;, vil visualiseringer blive vist i halv størrelse, og reducerer dermed CPU-belastningen. (I øjeblikket kun anvendt ved visualiseringen &apos;Goom&apos;.)</translation>
    </message>
    <message>
        <source>Height for Visual Scaling</source>
        <translation>Lodret skalering af visualisering</translation>
    </message>
    <message>
        <source>Visualizations</source>
        <translation>Visualiseringer</translation>
    </message>
    <message>
        <source>List of visualizations to use during playback. Possible values are space-separated list of </source>
        <translation>Liste over visualiseringer, der skal anvendes ved afspilning. Mulige værdier er følgende (med mellemrum imellem) </translation>
    </message>
    <message>
        <source>MonoScope</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>StereoScope</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Spectrum</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Goom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Synaesthesia</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gears</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default Rip Quality</source>
        <translation>Standard kvalitet ved kopiering (rip)</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Lav</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Mellem</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Høj</translation>
    </message>
    <message>
        <source>Perfect</source>
        <translation>Perfekt</translation>
    </message>
    <message>
        <source>Default quality for new CD rips.</source>
        <translation>Fastsætter standard-kvaliteten ved nye CD-kopieringer (rip).</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Generelle indstillinger</translation>
    </message>
    <message>
        <source>Playback Settings</source>
        <translation>Indstillinger for afspilning</translation>
    </message>
    <message>
        <source>Visualization Settings</source>
        <translation>Indstillinger for visualisering</translation>
    </message>
    <message>
        <source>CD Ripper Settings</source>
        <translation>Indstillinger for CD-kopiering</translation>
    </message>
    <message>
        <source>MPEG Layer 1/2/3 Audio (MAD decoder)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown Artist</source>
        <translation>Ukendt kunstner</translation>
    </message>
    <message>
        <source>Unknown Album</source>
        <translation>Ukendt album</translation>
    </message>
    <message>
        <source>Unknown Genre</source>
        <translation>Ukendt genre</translation>
    </message>
    <message>
        <source>CD -- none</source>
        <translation>CD -- ingen</translation>
    </message>
    <message>
        <source>All My Music</source>
        <translation>Al min musik</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>title</source>
        <translation>titel</translation>
    </message>
    <message>
        <source>Missing database entry: %1</source>
        <translation>Manglende post i database: %1</translation>
    </message>
    <message>
        <source> ~ </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ooops</source>
        <translation>Hovsa</translation>
    </message>
    <message>
        <source>%1 ~ %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not Initialized</source>
        <translation>Ikke initialiseret</translation>
    </message>
    <message>
        <source>oops</source>
        <translation>hovsa</translation>
    </message>
    <message>
        <source>,%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All My Playlists</source>
        <translation>Alle mine musiklister</translation>
    </message>
    <message>
        <source>Active Play Queue</source>
        <translation>Aktiv spillekø</translation>
    </message>
    <message>
        <source>Active Play Queue (%1)</source>
        <translation>Aktiv spillekø (%1)</translation>
    </message>
    <message>
        <source>Something is Wrong</source>
        <translation>Der er noget galt</translation>
    </message>
    <message>
        <source>Visualization requires FFT library</source>
        <translation>Visualisering kræver FFT biblioteksfil</translation>
    </message>
    <message>
        <source>Did you run configure?</source>
        <translation>Har du kørt konfigurations-scriptet?</translation>
    </message>
    <message>
        <source>and</source>
        <translation>og</translation>
    </message>
    <message>
        <source>Use variable bitrates</source>
        <translation>Anvend variabel bitrate</translation>
    </message>
    <message>
        <source>If set, the MP3 encoder will use variable bitrates (VBR) except for the low quality setting. The Ogg encoder will always use variable bitrates.</source>
        <translation>Hvis dette felt er markeret, vil MP3-algoritmen anvende variable bitrater (VBR) undtaget ved indstillingen &apos;lav kvalitet&apos;. Ogg-algoritmen vil dog altid anvende variable bitrater.</translation>
    </message>
    <message>
        <source>AlbumArt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD Ripper Settings (part 2)</source>
        <translation>Indstillinger for CD-kopiering (del 2)</translation>
    </message>
    <message>
        <source>Enable CD Writing.</source>
        <translation>Anvend skrivning af CD&apos;er</translation>
    </message>
    <message>
        <source>Requires a SCSI or an IDE-SCSI CD Writer.</source>
        <translation>Kræver en SCSI eller IDE-SCSI CD-brænder.</translation>
    </message>
    <message>
        <source>CD-Writer Device</source>
        <translation>Enhed for CD-brænding</translation>
    </message>
    <message>
        <source>Select the SCSI Device for CD Writing.  If your IDE device is not present, try adding hdd(or hdc/hdb)=ide-scsi to your boot options</source>
        <translation>Vælg SCSI-enheden til CD-brænding. Hvis din IDE-enhed ikke er tilgængelig, så prøv at tilføje hdd(eller hdc/hdb)=ide-scsi til dine boot-options</translation>
    </message>
    <message>
        <source>Disk Size</source>
        <translation>Disk-størrelse</translation>
    </message>
    <message>
        <source>650MB/75min</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>700MB/80min</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default CD Capacity.</source>
        <translation>Standard CD-kapacitet</translation>
    </message>
    <message>
        <source>Enable directories on MP3 Creation</source>
        <translation>Anvend underbiblioteker ved MP3-generering</translation>
    </message>
    <message>
        <source>CD Write Speed</source>
        <translation>Hastighed ved CD-brænding</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatisk</translation>
    </message>
    <message>
        <source>1x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>8x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>16x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD Writer speed. Auto will use the recomended speed.</source>
        <translation>Hastigheden som CD-brænderen anvender. Det anbefales at anvende &apos;Automatisk&apos;.</translation>
    </message>
    <message>
        <source>CD Blanking Type</source>
        <translation>Metode ved sletning af CDRW</translation>
    </message>
    <message>
        <source>Fast</source>
        <translation>Hurtig</translation>
    </message>
    <message>
        <source>Complete</source>
        <translation>Komplet</translation>
    </message>
    <message>
        <source>Blanking Method. Fast takes 1 minute. Complete can take up to 20 minutes.</source>
        <translation>Fastsætter metoden, hvorved CDRW-skiver slettes for tidligere data. &apos;Hurtig&apos; tager ca. 1 minut. &apos;Komplet&apos; kan tage op til 20 minutter.</translation>
    </message>
    <message>
        <source>CD Recording Settings</source>
        <translation>Indstillinger for CD-brænding</translation>
    </message>
    <message>
        <source>Artists</source>
        <translation>Kunstnere</translation>
    </message>
    <message>
        <source>Creating CD File System</source>
        <translation>Genererer CD-filsystem</translation>
    </message>
    <message>
        <source>Burning CD</source>
        <translation>Brænder CD</translation>
    </message>
    <message>
        <source>?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Order in which to sort the Music Tree. Possible values are a space-separated list of genre, splitartist, artist, album, and title OR the keyword &quot;directory&quot; to indicate that the onscreen tree mirrors the filesystem.</source>
        <translation>Orden for musik-hierarkiet. Mulige værdier er en liste (adskilt af mellemrum) med følgende mulige værdier: genre, splitartist, artist, album, og title ELLER &quot;directory&quot; for at indikere at billedet på skærmen har samme struktur som filsystemet.</translation>
    </message>
    <message>
        <source>CD: %1 ~ %2 - %3</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Ripper</name>
    <message>
        <source>Please select a quality level and check the album information below:</source>
        <translation>Vælgt venligst et kvalitets-niveau og kontrollér album-informationen nedenfor:</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Lav</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Mellem</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Høj</translation>
    </message>
    <message>
        <source>Perfect</source>
        <translation>Perfekt</translation>
    </message>
    <message>
        <source>Artist: </source>
        <translation>Kunstner: </translation>
    </message>
    <message>
        <source>Album: </source>
        <translation>Album: </translation>
    </message>
    <message>
        <source>Import this CD</source>
        <translation>Importér denne CD</translation>
    </message>
    <message>
        <source>Importing CD:
</source>
        <translation>Importerer CD:
</translation>
    </message>
    <message>
        <source>Copying from CD:
</source>
        <translation>Kopierer fra CD:
</translation>
    </message>
    <message>
        <source>Genre: </source>
        <translation>Genre:</translation>
    </message>
    <message>
        <source>Ripping...</source>
        <translation>Kopierer...</translation>
    </message>
    <message>
        <source>Multi-Artist?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch Titles &amp;&amp; Artists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmartPLCriteriaRow</name>
    <message>
        <source>Select an Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select an Album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select a Genre</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select a Title</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmartPLOrderByDialog</name>
    <message>
        <source>Order By Fields</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2 Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3 Move Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4 Move Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>5 Ascending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ascending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>6 Descending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Descending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>7 OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">Ok</translation>
    </message>
</context>
<context>
    <name>SmartPLResultViewer</name>
    <message>
        <source>Smart Playlist Result Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Genre</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Year</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Track No.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmartPlaylistDialog</name>
    <message>
        <source>Smart Playlists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2 New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3 Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4 Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete this SmartPlaylist?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmartPlaylistEditor</name>
    <message>
        <source>Smart Playlist Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Category:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Match</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Any</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Of The Following Conditions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Order By:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Matches:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Limit:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source></source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Smart Playlist Categories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New Category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename Category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete this Category?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>It will also delete any Smart Playlists belonging to this category.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Please Wait...</source>
        <translation>Vent venligst...</translation>
    </message>
    <message>
        <source>Track Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artist:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Album:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Genre:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Year:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Track No.:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rating:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play Count:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last Play:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Compilation:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filename:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
